import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.common.v1 import types_pb2 as _types_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MCPProfile(_message.Message):
    __slots__ = ("id", "user_id", "customer_id", "project_id", "name", "description", "url", "status", "error_message", "security_policy_type", "security_policy_value", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_VALUE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    customer_id: str
    project_id: str
    name: str
    description: str
    url: str
    status: str
    error_message: str
    security_policy_type: str
    security_policy_value: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., url: _Optional[str] = ..., status: _Optional[str] = ..., error_message: _Optional[str] = ..., security_policy_type: _Optional[str] = ..., security_policy_value: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class MCPCatalogServer(_message.Message):
    __slots__ = ("id", "name", "description", "url", "icon_url", "categories", "note", "authentication", "requires_auth", "requires_profile", "is_enabled", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    ICON_URL_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    NOTE_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_AUTH_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_PROFILE_FIELD_NUMBER: _ClassVar[int]
    IS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    url: str
    icon_url: str
    categories: _containers.RepeatedScalarFieldContainer[str]
    note: str
    authentication: str
    requires_auth: bool
    requires_profile: bool
    is_enabled: bool
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., url: _Optional[str] = ..., icon_url: _Optional[str] = ..., categories: _Optional[_Iterable[str]] = ..., note: _Optional[str] = ..., authentication: _Optional[str] = ..., requires_auth: _Optional[bool] = ..., requires_profile: _Optional[bool] = ..., is_enabled: _Optional[bool] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateMCPProfileRequest(_message.Message):
    __slots__ = ("user_id", "name", "description", "security_policy_type", "security_policy_value", "customer_id", "project_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_VALUE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    name: str
    description: str
    security_policy_type: str
    security_policy_value: str
    customer_id: str
    project_id: str
    def __init__(self, user_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., security_policy_type: _Optional[str] = ..., security_policy_value: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class GetMCPProfileRequest(_message.Message):
    __slots__ = ("user_id", "profile_id", "customer_id", "project_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    profile_id: str
    customer_id: str
    project_id: str
    def __init__(self, user_id: _Optional[str] = ..., profile_id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListMCPProfilesRequest(_message.Message):
    __slots__ = ("user_id", "page", "customer_id", "project_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    page: _types_pb2.PageRequest
    customer_id: str
    project_id: str
    def __init__(self, user_id: _Optional[str] = ..., page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListMCPProfilesResponse(_message.Message):
    __slots__ = ("profiles", "page")
    PROFILES_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    profiles: _containers.RepeatedCompositeFieldContainer[MCPProfile]
    page: _types_pb2.PageResponse
    def __init__(self, profiles: _Optional[_Iterable[_Union[MCPProfile, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class UpdateMCPProfileRequest(_message.Message):
    __slots__ = ("user_id", "profile_id", "name", "description", "security_policy_type", "security_policy_value", "customer_id", "project_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_VALUE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    profile_id: str
    name: str
    description: str
    security_policy_type: str
    security_policy_value: str
    customer_id: str
    project_id: str
    def __init__(self, user_id: _Optional[str] = ..., profile_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., security_policy_type: _Optional[str] = ..., security_policy_value: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class DeleteMCPProfileRequest(_message.Message):
    __slots__ = ("user_id", "profile_id", "customer_id", "project_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    profile_id: str
    customer_id: str
    project_id: str
    def __init__(self, user_id: _Optional[str] = ..., profile_id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class UpsertCatalogServerRequest(_message.Message):
    __slots__ = ("id", "name", "description", "url", "icon_url", "categories", "note", "authentication", "requires_auth", "requires_profile")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    ICON_URL_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    NOTE_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_AUTH_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_PROFILE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    url: str
    icon_url: str
    categories: _containers.RepeatedScalarFieldContainer[str]
    note: str
    authentication: str
    requires_auth: bool
    requires_profile: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., url: _Optional[str] = ..., icon_url: _Optional[str] = ..., categories: _Optional[_Iterable[str]] = ..., note: _Optional[str] = ..., authentication: _Optional[str] = ..., requires_auth: _Optional[bool] = ..., requires_profile: _Optional[bool] = ...) -> None: ...

class GetCatalogServerRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListCatalogServersRequest(_message.Message):
    __slots__ = ("include_disabled", "page")
    INCLUDE_DISABLED_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    include_disabled: bool
    page: _types_pb2.PageRequest
    def __init__(self, include_disabled: _Optional[bool] = ..., page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListCatalogServersResponse(_message.Message):
    __slots__ = ("servers", "page")
    SERVERS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    servers: _containers.RepeatedCompositeFieldContainer[MCPCatalogServer]
    page: _types_pb2.PageResponse
    def __init__(self, servers: _Optional[_Iterable[_Union[MCPCatalogServer, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class DeleteCatalogServerRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class SetCatalogServerEnabledRequest(_message.Message):
    __slots__ = ("id", "enabled")
    ID_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    id: str
    enabled: bool
    def __init__(self, id: _Optional[str] = ..., enabled: _Optional[bool] = ...) -> None: ...



from google.api import annotations_pb2 as _annotations_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EnterpriseContext(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "organization_unit")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_UNIT_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    organization_unit: str
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., organization_unit: _Optional[str] = ...) -> None: ...

class CreateApiKeyRequest(_message.Message):
    __slots__ = ("user_id", "user_key_address", "name", "enterprise_context")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    USER_KEY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ENTERPRISE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    user_key_address: str
    name: str
    enterprise_context: EnterpriseContext
    def __init__(self, user_id: _Optional[str] = ..., user_key_address: _Optional[str] = ..., name: _Optional[str] = ..., enterprise_context: _Optional[_Union[EnterpriseContext, _Mapping]] = ...) -> None: ...

class CreateApiKeyResponse(_message.Message):
    __slots__ = ("id", "user_id", "api_key", "prefix", "key_hash", "key_address", "key_suffix")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    KEY_HASH_FIELD_NUMBER: _ClassVar[int]
    KEY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    KEY_SUFFIX_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    api_key: str
    prefix: str
    key_hash: str
    key_address: str
    key_suffix: str
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., api_key: _Optional[str] = ..., prefix: _Optional[str] = ..., key_hash: _Optional[str] = ..., key_address: _Optional[str] = ..., key_suffix: _Optional[str] = ...) -> None: ...

class UpdateApiKeyRequest(_message.Message):
    __slots__ = ("user_id", "key_id", "name", "is_active")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    key_id: str
    name: str
    is_active: bool
    def __init__(self, user_id: _Optional[str] = ..., key_id: _Optional[str] = ..., name: _Optional[str] = ..., is_active: _Optional[bool] = ...) -> None: ...

class UpdateApiKeyResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class DeleteApiKeyRequest(_message.Message):
    __slots__ = ("user_id", "key_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    key_id: str
    def __init__(self, user_id: _Optional[str] = ..., key_id: _Optional[str] = ...) -> None: ...

class DeleteApiKeyResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/clients/v1/clients.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/clients/v1/clients.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtars/clients/v1/clients.proto\x12\x0ftars.clients.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\x84\x01\n\x11\x45nterpriseContext\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x02 \x01(\tR\x0bworkspaceId\x12+\n\x11organization_unit\x18\x03 \x01(\tR\x10organizationUnit\"\xbd\x04\n\tClientKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x16\n\x06prefix\x18\x03 \x01(\tR\x06prefix\x12\x19\n\x08key_hash\x18\x04 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x05 \x01(\tR\nkeyAddress\x12\x1d\n\nkey_suffix\x18\x06 \x01(\tR\tkeySuffix\x12\x1b\n\tis_active\x18\x07 \x01(\x08R\x08isActive\x12\x1d\n\nis_deleted\x18\x08 \x01(\x08R\tisDeleted\x12\x36\n\x05state\x18\t \x01(\x0e\x32 .tars.clients.v1.KeyVersionStateR\x05state\x12O\n\x13rotation_disable_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x11rotationDisableAt\x88\x01\x01\x12O\n\x13rotation_destroy_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x11rotationDestroyAt\x88\x01\x01\x12\x42\n\x0c\x64\x65stroyed_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\x0b\x64\x65stroyedAt\x88\x01\x01\x42\x16\n\x14_rotation_disable_atB\x16\n\x14_rotation_destroy_atB\x0f\n\r_destroyed_at\"\xb7\x01\n\x06\x43lient\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x14\n\x05title\x18\x04 \x01(\tR\x05title\x12\x1f\n\x0b\x63ustomer_id\x18\x05 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x06 \x01(\tR\tprojectId\x12.\n\x04keys\x18\x03 \x03(\x0b\x32\x1a.tars.clients.v1.ClientKeyR\x04keys\"\xf8\x01\n\x1a\x43reateClientWithKeyRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x14\n\x05title\x18\x03 \x01(\tR\x05title\x12\x19\n\x08key_name\x18\x04 \x01(\tR\x07keyName\x12Q\n\x12\x65nterprise_context\x18\x06 \x01(\x0b\x32\".tars.clients.v1.EnterpriseContextR\x11\x65nterpriseContextJ\x04\x08\x05\x10\x06R\x10user_key_address\"\xe6\x01\n\x1b\x43reateClientWithKeyResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12 \n\x0c\x61pi_key_once\x18\x03 \x01(\tR\napiKeyOnce\x12\x16\n\x06prefix\x18\x04 \x01(\tR\x06prefix\x12\x19\n\x08key_hash\x18\x05 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x06 \x01(\tR\nkeyAddress\x12\x1d\n\nkey_suffix\x18\x07 \x01(\tR\tkeySuffix\"\x95\x01\n\x15\x41\x64\x64KeyToClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12\x1a\n\x06key_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x05keyId\"2\n\x16\x41\x64\x64KeyToClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\x8e\x04\n\x18RotateKeyInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12(\n\x10user_key_address\x18\x04 \x01(\tR\x0euserKeyAddress\x12\x19\n\x08key_name\x18\x05 \x01(\tR\x07keyName\x12Q\n\x12\x65nterprise_context\x18\x06 \x01(\x0b\x32\".tars.clients.v1.EnterpriseContextR\x11\x65nterpriseContext\x12\x1c\n\nold_key_id\x18\x07 \x01(\tR\x08oldKeyId\x12G\n\x12old_key_disable_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0foldKeyDisableAt\x12G\n\x12old_key_destroy_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0foldKeyDestroyAt\x12#\n\rdisable_after\x18\n \x01(\tR\x0c\x64isableAfter\x12#\n\rdestroy_after\x18\x0b \x01(\tR\x0c\x64\x65stroyAfter\"\xa3\x02\n\x19RotateKeyInClientResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12 \n\x0c\x61pi_key_once\x18\x03 \x01(\tR\napiKeyOnce\x12\x16\n\x06prefix\x18\x04 \x01(\tR\x06prefix\x12\x19\n\x08key_hash\x18\x05 \x01(\tR\x07keyHash\x12\x1f\n\x0bkey_address\x18\x06 \x01(\tR\nkeyAddress\x12\x1d\n\nkey_suffix\x18\x07 \x01(\tR\tkeySuffix\x12=\n\x1bold_key_lifecycle_scheduled\x18\x08 \x01(\x08R\x18oldKeyLifecycleScheduled\"\xaa\x01\n DisableKeyVersionInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\"=\n!DisableKeyVersionInClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xa9\x01\n\x1f\x45nableKeyVersionInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\"<\n EnableKeyVersionInClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xaa\x01\n DestroyKeyVersionInClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\"=\n!DestroyKeyVersionInClientResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"\xba\x03\n EmergencyRevokeKeyVersionRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12$\n\x0bkey_version\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nkeyVersion\x12\x31\n\x14generate_replacement\x18\x05 \x01(\x08R\x13generateReplacement\x12\x30\n\x14replacement_key_name\x18\x06 \x01(\tR\x12replacementKeyName\x12?\n\x1creplacement_user_key_address\x18\x07 \x01(\tR\x19replacementUserKeyAddress\x12h\n\x1ereplacement_enterprise_context\x18\x08 \x01(\x0b\x32\".tars.clients.v1.EnterpriseContextR\x1creplacementEnterpriseContext\"\xa0\x01\n!EmergencyRevokeKeyVersionResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12Q\n\x0breplacement\x18\x02 \x01(\x0b\x32*.tars.clients.v1.RotateKeyInClientResponseH\x00R\x0breplacement\x88\x01\x01\x42\x0e\n\x0c_replacement\"t\n\x10GetClientRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\"D\n\x11GetClientResponse\x12/\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.tars.clients.v1.ClientR\x06\x63lient\"T\n\x12ListClientsRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\"H\n\x13ListClientsResponse\x12\x31\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x17.tars.clients.v1.ClientR\x07\x63lients\"\x97\x01\n\x18UpdateClientTitleRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12 \n\tclient_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12\x19\n\x05title\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x05title\"L\n\x19UpdateClientTitleResponse\x12/\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x17.tars.clients.v1.ClientR\x06\x63lient*\x94\x01\n\x0fKeyVersionState\x12!\n\x1dKEY_VERSION_STATE_UNSPECIFIED\x10\x00\x12\x1d\n\x19KEY_VERSION_STATE_ENABLED\x10\x01\x12\x1e\n\x1aKEY_VERSION_STATE_DISABLED\x10\x02\x12\x1f\n\x1bKEY_VERSION_STATE_DESTROYED\x10\x03\x32\xce\x15\n\x0e\x43lientsService\x12\xf1\x01\n\x13\x43reateClientWithKey\x12+.tars.clients.v1.CreateClientWithKeyRequest\x1a,.tars.clients.v1.CreateClientWithKeyResponse\"\x7f\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x11:\x07\x63lients:\x06\x63reate\xa2\xb5\x18\x0f\x43reate a client\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id}/projects/{project_id}/clients:\x01*\x12\xd4\x01\n\x0bListClients\x12#.tars.clients.v1.ListClientsRequest\x1a$.tars.clients.v1.ListClientsResponse\"z\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0f:\x07\x63lients:\x04list\xa2\xb5\x18\x0cList clients\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02;\x12\x39/v1/customers/{customer_id}/projects/{project_id}/clients\x12\xda\x01\n\tGetClient\x12!.tars.clients.v1.GetClientRequest\x1a\".tars.clients.v1.GetClientResponse\"\x85\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0e:\x07\x63lients:\x03get\xa2\xb5\x18\x0cGet a client\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02G\x12\x45/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}\x12\xf8\x01\n\x11UpdateClientTitle\x12).tars.clients.v1.UpdateClientTitleRequest\x1a*.tars.clients.v1.UpdateClientTitleResponse\"\x8b\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x11:\x07\x63lients:\x06update\xa2\xb5\x18\x0fUpdate a client\xaa\xb5\x18\x07\x43lients\x82\xd3\xe4\x93\x02J2E/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}:\x01*\x12\xfd\x01\n\x0e\x41\x64\x64KeyToClient\x12&.tars.clients.v1.AddKeyToClientRequest\x1a\'.tars.clients.v1.AddKeyToClientResponse\"\x99\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x14:\x07\x63lients:\x04keys:\x03\x61\x64\x64\xa2\xb5\x18\x18\x41ttach a key to a client\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02O\"J/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys:\x01*\x12\x8b\x02\n\x11RotateKeyInClient\x12).tars.clients.v1.RotateKeyInClientRequest\x1a*.tars.clients.v1.RotateKeyInClientResponse\"\x9e\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x07\x63lients:\x04keys:\x06rotate\xa2\xb5\x18\x13Rotate a client key\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02V\"Q/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/rotate:\x01*\x12\xbc\x02\n\x19\x44isableKeyVersionInClient\x12\x31.tars.clients.v1.DisableKeyVersionInClientRequest\x1a\x32.tars.clients.v1.DisableKeyVersionInClientResponse\"\xb7\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x18:\x07\x63lients:\x04keys:\x07\x64isable\xa2\xb5\x18\x1c\x44isable a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02\x65\"`/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/disable:\x01*\x12\xb6\x02\n\x18\x45nableKeyVersionInClient\x12\x30.tars.clients.v1.EnableKeyVersionInClientRequest\x1a\x31.tars.clients.v1.EnableKeyVersionInClientResponse\"\xb4\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x07\x63lients:\x04keys:\x06\x65nable\xa2\xb5\x18\x1b\x45nable a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02\x64\"_/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/enable:\x01*\x12\xb1\x02\n\x19\x44\x65stroyKeyVersionInClient\x12\x31.tars.clients.v1.DestroyKeyVersionInClientRequest\x1a\x32.tars.clients.v1.DestroyKeyVersionInClientResponse\"\xac\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x18:\x07\x63lients:\x04keys:\x07\x64\x65stroy\xa2\xb5\x18\x1c\x44\x65stroy a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02Z*X/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}\x12\xde\x02\n\x19\x45mergencyRevokeKeyVersion\x12\x31.tars.clients.v1.EmergencyRevokeKeyVersionRequest\x1a\x32.tars.clients.v1.EmergencyRevokeKeyVersionResponse\"\xd9\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18!:\x07\x63lients:\x04keys:\x10\x65mergency-revoke\xa2\xb5\x18%Emergency-revoke a client key version\xaa\xb5\x18\x04Keys\x82\xd3\xe4\x93\x02n\"i/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/emergency-revoke:\x01*B\xbc\x01\n\x13\x63om.tars.clients.v1B\x0c\x43lientsProtoP\x01Z9github.com/tetrateio/fraser/api/tars/clients/v1;clientsv1\xa2\x02\x03TCX\xaa\x02\x0fTars.Clients.V1\xca\x02\x0fTars\\Clients\\V1\xe2\x02\x1bTars\\Clients\\V1\\GPBMetadata\xea\x02\x11Tars::Clients::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.clients.v1.clients_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.tars.clients.v1B\014ClientsProtoP\001Z9github.com/tetrateio/fraser/api/tars/clients/v1;clientsv1\242\002\003TCX\252\002\017Tars.Clients.V1\312\002\017Tars\\Clients\\V1\342\002\033Tars\\Clients\\V1\\GPBMetadata\352\002\021Tars::Clients::V1'
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_ADDKEYTOCLIENTREQUEST'].fields_by_name['key_id']._serialized_options = b'\340A\002'
  _globals['_ROTATEKEYINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ROTATEKEYINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['key_version']._loaded_options = None
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST'].fields_by_name['key_version']._serialized_options = b'\340A\002'
  _globals['_GETCLIENTREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_GETCLIENTREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['client_id']._serialized_options = b'\340A\002'
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATECLIENTTITLEREQUEST'].fields_by_name['title']._serialized_options = b'\340A\002'
  _globals['_CLIENTSSERVICE'].methods_by_name['CreateClientWithKey']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['CreateClientWithKey']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\021:\007clients:\006create\242\265\030\017Create a client\252\265\030\007Clients\202\323\344\223\002>\"9/v1/customers/{customer_id}/projects/{project_id}/clients:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['ListClients']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['ListClients']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\017:\007clients:\004list\242\265\030\014List clients\252\265\030\007Clients\202\323\344\223\002;\0229/v1/customers/{customer_id}/projects/{project_id}/clients'
  _globals['_CLIENTSSERVICE'].methods_by_name['GetClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['GetClient']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\016:\007clients:\003get\242\265\030\014Get a client\252\265\030\007Clients\202\323\344\223\002G\022E/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}'
  _globals['_CLIENTSSERVICE'].methods_by_name['UpdateClientTitle']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['UpdateClientTitle']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\021:\007clients:\006update\242\265\030\017Update a client\252\265\030\007Clients\202\323\344\223\002J2E/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['AddKeyToClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['AddKeyToClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\024:\007clients:\004keys:\003add\242\265\030\030Attach a key to a client\252\265\030\004Keys\202\323\344\223\002O\"J/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['RotateKeyInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['RotateKeyInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\027:\007clients:\004keys:\006rotate\242\265\030\023Rotate a client key\252\265\030\004Keys\202\323\344\223\002V\"Q/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/rotate:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['DisableKeyVersionInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['DisableKeyVersionInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\030:\007clients:\004keys:\007disable\242\265\030\034Disable a client key version\252\265\030\004Keys\202\323\344\223\002e\"`/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/disable:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['EnableKeyVersionInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['EnableKeyVersionInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\027:\007clients:\004keys:\006enable\242\265\030\033Enable a client key version\252\265\030\004Keys\202\323\344\223\002d\"_/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/enable:\001*'
  _globals['_CLIENTSSERVICE'].methods_by_name['DestroyKeyVersionInClient']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['DestroyKeyVersionInClient']._serialized_options = b'\212\265\030\004\n\002\003\001\222\265\030\030:\007clients:\004keys:\007destroy\242\265\030\034Destroy a client key version\252\265\030\004Keys\202\323\344\223\002Z*X/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}'
  _globals['_CLIENTSSERVICE'].methods_by_name['EmergencyRevokeKeyVersion']._loaded_options = None
  _globals['_CLIENTSSERVICE'].methods_by_name['EmergencyRevokeKeyVersion']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030!:\007clients:\004keys:\020emergency-revoke\242\265\030%Emergency-revoke a client key version\252\265\030\004Keys\202\323\344\223\002n\"i/v1/customers/{customer_id}/projects/{project_id}/clients/{client_id}/keys/{key_version}/emergency-revoke:\001*'
  _globals['_KEYVERSIONSTATE']._serialized_start=4530
  _globals['_KEYVERSIONSTATE']._serialized_end=4678
  _globals['_ENTERPRISECONTEXT']._serialized_start=228
  _globals['_ENTERPRISECONTEXT']._serialized_end=360
  _globals['_CLIENTKEY']._serialized_start=363
  _globals['_CLIENTKEY']._serialized_end=936
  _globals['_CLIENT']._serialized_start=939
  _globals['_CLIENT']._serialized_end=1122
  _globals['_CREATECLIENTWITHKEYREQUEST']._serialized_start=1125
  _globals['_CREATECLIENTWITHKEYREQUEST']._serialized_end=1373
  _globals['_CREATECLIENTWITHKEYRESPONSE']._serialized_start=1376
  _globals['_CREATECLIENTWITHKEYRESPONSE']._serialized_end=1606
  _globals['_ADDKEYTOCLIENTREQUEST']._serialized_start=1609
  _globals['_ADDKEYTOCLIENTREQUEST']._serialized_end=1758
  _globals['_ADDKEYTOCLIENTRESPONSE']._serialized_start=1760
  _globals['_ADDKEYTOCLIENTRESPONSE']._serialized_end=1810
  _globals['_ROTATEKEYINCLIENTREQUEST']._serialized_start=1813
  _globals['_ROTATEKEYINCLIENTREQUEST']._serialized_end=2339
  _globals['_ROTATEKEYINCLIENTRESPONSE']._serialized_start=2342
  _globals['_ROTATEKEYINCLIENTRESPONSE']._serialized_end=2633
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST']._serialized_start=2636
  _globals['_DISABLEKEYVERSIONINCLIENTREQUEST']._serialized_end=2806
  _globals['_DISABLEKEYVERSIONINCLIENTRESPONSE']._serialized_start=2808
  _globals['_DISABLEKEYVERSIONINCLIENTRESPONSE']._serialized_end=2869
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST']._serialized_start=2872
  _globals['_ENABLEKEYVERSIONINCLIENTREQUEST']._serialized_end=3041
  _globals['_ENABLEKEYVERSIONINCLIENTRESPONSE']._serialized_start=3043
  _globals['_ENABLEKEYVERSIONINCLIENTRESPONSE']._serialized_end=3103
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST']._serialized_start=3106
  _globals['_DESTROYKEYVERSIONINCLIENTREQUEST']._serialized_end=3276
  _globals['_DESTROYKEYVERSIONINCLIENTRESPONSE']._serialized_start=3278
  _globals['_DESTROYKEYVERSIONINCLIENTRESPONSE']._serialized_end=3339
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST']._serialized_start=3342
  _globals['_EMERGENCYREVOKEKEYVERSIONREQUEST']._serialized_end=3784
  _globals['_EMERGENCYREVOKEKEYVERSIONRESPONSE']._serialized_start=3787
  _globals['_EMERGENCYREVOKEKEYVERSIONRESPONSE']._serialized_end=3947
  _globals['_GETCLIENTREQUEST']._serialized_start=3949
  _globals['_GETCLIENTREQUEST']._serialized_end=4065
  _globals['_GETCLIENTRESPONSE']._serialized_start=4067
  _globals['_GETCLIENTRESPONSE']._serialized_end=4135
  _globals['_LISTCLIENTSREQUEST']._serialized_start=4137
  _globals['_LISTCLIENTSREQUEST']._serialized_end=4221
  _globals['_LISTCLIENTSRESPONSE']._serialized_start=4223
  _globals['_LISTCLIENTSRESPONSE']._serialized_end=4295
  _globals['_UPDATECLIENTTITLEREQUEST']._serialized_start=4298
  _globals['_UPDATECLIENTTITLEREQUEST']._serialized_end=4449
  _globals['_UPDATECLIENTTITLERESPONSE']._serialized_start=4451
  _globals['_UPDATECLIENTTITLERESPONSE']._serialized_end=4527
  _globals['_CLIENTSSERVICE']._serialized_start=4681
  _globals['_CLIENTSSERVICE']._serialized_end=7447
# @@protoc_insertion_point(module_scope)



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetRevocationListRequest(_message.Message):
    __slots__ = ("since", "limit")
    SINCE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    since: _timestamp_pb2.Timestamp
    limit: int
    def __init__(self, since: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., limit: _Optional[int] = ...) -> None: ...

class GetRevocationListResponse(_message.Message):
    __slots__ = ("revocations", "snapshot_at", "total_count")
    REVOCATIONS_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_AT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    revocations: _containers.RepeatedCompositeFieldContainer[RevokedTokenInfo]
    snapshot_at: _timestamp_pb2.Timestamp
    total_count: int
    def __init__(self, revocations: _Optional[_Iterable[_Union[RevokedTokenInfo, _Mapping]]] = ..., snapshot_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., total_count: _Optional[int] = ...) -> None: ...

class RevokedTokenInfo(_message.Message):
    __slots__ = ("jti", "revoked_at", "reason")
    JTI_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    jti: str
    revoked_at: _timestamp_pb2.Timestamp
    reason: str
    def __init__(self, jti: _Optional[str] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., reason: _Optional[str] = ...) -> None: ...

class UpdateLastUsedRequest(_message.Message):
    __slots__ = ("jti", "used_at")
    JTI_FIELD_NUMBER: _ClassVar[int]
    USED_AT_FIELD_NUMBER: _ClassVar[int]
    jti: str
    used_at: _timestamp_pb2.Timestamp
    def __init__(self, jti: _Optional[str] = ..., used_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class UpdateLastUsedResponse(_message.Message):
    __slots__ = ("success", "recorded_at")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RECORDED_AT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    recorded_at: _timestamp_pb2.Timestamp
    def __init__(self, success: _Optional[bool] = ..., recorded_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Purpose(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PURPOSE_UNSPECIFIED: _ClassVar[Purpose]
    PURPOSE_AUDIT_SIGNING: _ClassVar[Purpose]
    PURPOSE_BYOK: _ClassVar[Purpose]
    PURPOSE_JWKS_SIGNING: _ClassVar[Purpose]
    PURPOSE_WEBHOOK_SECRET: _ClassVar[Purpose]
    PURPOSE_DATAPLANE_SA: _ClassVar[Purpose]
PURPOSE_UNSPECIFIED: Purpose
PURPOSE_AUDIT_SIGNING: Purpose
PURPOSE_BYOK: Purpose
PURPOSE_JWKS_SIGNING: Purpose
PURPOSE_WEBHOOK_SECRET: Purpose
PURPOSE_DATAPLANE_SA: Purpose

class SecretRef(_message.Message):
    __slots__ = ("id", "purpose", "kek_version", "label", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    KEK_VERSION_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    purpose: Purpose
    kek_version: int
    label: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., purpose: _Optional[_Union[Purpose, str]] = ..., kek_version: _Optional[int] = ..., label: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class PutSecretRequest(_message.Message):
    __slots__ = ("purpose", "plaintext", "label")
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    PLAINTEXT_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    purpose: Purpose
    plaintext: str
    label: str
    def __init__(self, purpose: _Optional[_Union[Purpose, str]] = ..., plaintext: _Optional[str] = ..., label: _Optional[str] = ...) -> None: ...

class PutSecretResponse(_message.Message):
    __slots__ = ("ref",)
    REF_FIELD_NUMBER: _ClassVar[int]
    ref: SecretRef
    def __init__(self, ref: _Optional[_Union[SecretRef, _Mapping]] = ...) -> None: ...

class GetSecretRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSecretResponse(_message.Message):
    __slots__ = ("ref", "plaintext")
    REF_FIELD_NUMBER: _ClassVar[int]
    PLAINTEXT_FIELD_NUMBER: _ClassVar[int]
    ref: SecretRef
    plaintext: str
    def __init__(self, ref: _Optional[_Union[SecretRef, _Mapping]] = ..., plaintext: _Optional[str] = ...) -> None: ...

class RotateResourceDekRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class RotateResourceDekResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class EraseSecretRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class EraseSecretResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RotatePurposeKekRequest(_message.Message):
    __slots__ = ("purpose",)
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    purpose: Purpose
    def __init__(self, purpose: _Optional[_Union[Purpose, str]] = ...) -> None: ...

class RotatePurposeKekResponse(_message.Message):
    __slots__ = ("operation_id",)
    OPERATION_ID_FIELD_NUMBER: _ClassVar[int]
    operation_id: str
    def __init__(self, operation_id: _Optional[str] = ...) -> None: ...

class RotateMasterKekRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RotateMasterKekResponse(_message.Message):
    __slots__ = ("operation_id",)
    OPERATION_ID_FIELD_NUMBER: _ClassVar[int]
    operation_id: str
    def __init__(self, operation_id: _Optional[str] = ...) -> None: ...

class SignRequest(_message.Message):
    __slots__ = ("purpose", "payload")
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    purpose: Purpose
    payload: bytes
    def __init__(self, purpose: _Optional[_Union[Purpose, str]] = ..., payload: _Optional[bytes] = ...) -> None: ...

class SignResponse(_message.Message):
    __slots__ = ("signature", "kek_version")
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    KEK_VERSION_FIELD_NUMBER: _ClassVar[int]
    signature: bytes
    kek_version: int
    def __init__(self, signature: _Optional[bytes] = ..., kek_version: _Optional[int] = ...) -> None: ...

class VerifyRequest(_message.Message):
    __slots__ = ("purpose", "payload", "signature")
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    purpose: Purpose
    payload: bytes
    signature: bytes
    def __init__(self, purpose: _Optional[_Union[Purpose, str]] = ..., payload: _Optional[bytes] = ..., signature: _Optional[bytes] = ...) -> None: ...

class VerifyResponse(_message.Message):
    __slots__ = ("valid", "kek_version")
    VALID_FIELD_NUMBER: _ClassVar[int]
    KEK_VERSION_FIELD_NUMBER: _ClassVar[int]
    valid: bool
    kek_version: int
    def __init__(self, valid: _Optional[bool] = ..., kek_version: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/common/v1/types.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/common/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1atars/common/v1/types.proto\x12\x0etars.common.v1\x1a\x1fgoogle/api/field_behavior.proto\"|\n\x0bPageRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x03 \x01(\tR\x06\x66ilter\x12\x19\n\x08order_by\x18\x04 \x01(\tR\x07orderBy\";\n\x0cPageResponse\x12+\n\x0fnext_page_token\x18\x01 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\"+\n\x0eIdempotencyKey\x12\x19\n\x05value\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05value\"\xf7\x02\n\x07Problem\x12\x17\n\x04type\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04type\x12\x19\n\x05title\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05title\x12\x1b\n\x06status\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x06status\x12\x1b\n\x06\x64\x65tail\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x06\x64\x65tail\x12\x1f\n\x08instance\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x08instance\x12\x1b\n\x06reason\x18\n \x01(\tB\x03\xe0\x41\x03R\x06reason\x12\x1b\n\x06\x64omain\x18\x0b \x01(\tB\x03\xe0\x41\x03R\x06\x64omain\x12\x46\n\x08metadata\x18\x0c \x03(\x0b\x32%.tars.common.v1.Problem.MetadataEntryB\x03\xe0\x41\x03R\x08metadata\x12\x1e\n\x08trace_id\x18\r \x01(\tB\x03\xe0\x41\x03R\x07traceId\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xd4\x03\n\x08IdPrefix\x12\x19\n\x15ID_PREFIX_UNSPECIFIED\x10\x00\x12\x16\n\x12ID_PREFIX_CUSTOMER\x10\x01\x12\x15\n\x11ID_PREFIX_PROJECT\x10\x02\x12\x17\n\x13ID_PREFIX_DATAPLANE\x10\x03\x12\x15\n\x11ID_PREFIX_API_KEY\x10\x04\x12\x17\n\x13ID_PREFIX_OPERATION\x10\x05\x12\x16\n\x12ID_PREFIX_IDENTITY\x10\x06\x12\x14\n\x10ID_PREFIX_BUDGET\x10\x07\x12\x16\n\x12ID_PREFIX_BYOK_KEY\x10\x08\x12\x15\n\x11ID_PREFIX_GATEWAY\x10\t\x12!\n\x1dID_PREFIX_PROJECT_GATEWAY_MAP\x10\n\x12\"\n\x1eID_PREFIX_DATAPLANE_CREDENTIAL\x10\x0b\x12\x16\n\x12ID_PREFIX_PROVIDER\x10\x0c\x12\x13\n\x0fID_PREFIX_MODEL\x10\r\x12\x1a\n\x16ID_PREFIX_BILLING_PLAN\x10\x0e\x12\x1a\n\x16ID_PREFIX_USAGE_RECORD\x10\x0f\x12\x15\n\x11ID_PREFIX_SESSION\x10\x10\x12\x15\n\x11ID_PREFIX_WEBHOOK\x10\x11\x42\xb3\x01\n\x12\x63om.tars.common.v1B\nTypesProtoP\x01Z7github.com/tetrateio/fraser/api/tars/common/v1;commonv1\xa2\x02\x03TCX\xaa\x02\x0eTars.Common.V1\xca\x02\x0eTars\\Common\\V1\xe2\x02\x1aTars\\Common\\V1\\GPBMetadata\xea\x02\x10Tars::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.common.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.common.v1B\nTypesProtoP\001Z7github.com/tetrateio/fraser/api/tars/common/v1;commonv1\242\002\003TCX\252\002\016Tars.Common.V1\312\002\016Tars\\Common\\V1\342\002\032Tars\\Common\\V1\\GPBMetadata\352\002\020Tars::Common::V1'
  _globals['_PAGERESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_PAGERESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _globals['_IDEMPOTENCYKEY'].fields_by_name['value']._loaded_options = None
  _globals['_IDEMPOTENCYKEY'].fields_by_name['value']._serialized_options = b'\340A\002'
  _globals['_PROBLEM_METADATAENTRY']._loaded_options = None
  _globals['_PROBLEM_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_PROBLEM'].fields_by_name['type']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['type']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['title']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['title']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['status']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['status']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['detail']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['detail']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['instance']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['instance']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['reason']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['reason']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['domain']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['domain']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['metadata']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['metadata']._serialized_options = b'\340A\003'
  _globals['_PROBLEM'].fields_by_name['trace_id']._loaded_options = None
  _globals['_PROBLEM'].fields_by_name['trace_id']._serialized_options = b'\340A\003'
  _globals['_IDPREFIX']._serialized_start=690
  _globals['_IDPREFIX']._serialized_end=1158
  _globals['_PAGEREQUEST']._serialized_start=79
  _globals['_PAGEREQUEST']._serialized_end=203
  _globals['_PAGERESPONSE']._serialized_start=205
  _globals['_PAGERESPONSE']._serialized_end=264
  _globals['_IDEMPOTENCYKEY']._serialized_start=266
  _globals['_IDEMPOTENCYKEY']._serialized_end=309
  _globals['_PROBLEM']._serialized_start=312
  _globals['_PROBLEM']._serialized_end=687
  _globals['_PROBLEM_METADATAENTRY']._serialized_start=628
  _globals['_PROBLEM_METADATAENTRY']._serialized_end=687
# @@protoc_insertion_point(module_scope)



"""Tetrate Agent Router (TARS) Python SDK.

A thin, idiomatic wrapper over the buf-generated protobuf-python messages
in ``agentrouter_sdk._gen``. The SDK speaks Connect-JSON over HTTP via
:mod:`httpx` -- the same wire protocol Connect-Go and Connect-ES use.

Quickstart::

    import os
    from agentrouter_sdk import Client

    router = Client(base_url=os.environ["AGENTROUTER_BASE_URL"])
    providers = router.catalog.list_providers().providers
    for p in providers:
        print(p.name)

Construct once and reuse; close when done (or use a ``with`` block).
"""

from __future__ import annotations

# Ensure the bundled _gen subtree is importable as top-level
# ``tars.<svc>.v1.<svc>_pb2`` and ``google.api.*``. Without this nudge, a
# consumer who installed agentrouter-sdk from PyPI would have to add the
# vendored proto path to sys.path themselves.
import os
import sys

_GEN_DIR = os.path.join(os.path.dirname(__file__), "_gen")
if _GEN_DIR not in sys.path:
    sys.path.insert(0, _GEN_DIR)

from .client import Client, Endpoints, RetryPolicy  # noqa: E402
from .errors import (  # noqa: E402
    ABORTED,
    ALREADY_EXISTS,
    DEADLINE_EXCEEDED,
    AgentrouterError,
    FailedPreconditionError,
    INVALID_ARGUMENT,
    NOT_FOUND,
    PERMISSION_DENIED,
    RETRYABLE,
    UNAUTHENTICATED,
    UNAVAILABLE,
    UNKNOWN,
)

# Standard environment variable names.
STANDARD_API_KEY_ENV = "AGENTROUTER_API_KEY"
STANDARD_BASE_URL_ENV = "AGENTROUTER_BASE_URL"
STANDARD_SESSION_TOKEN_ENV = "AGENTROUTER_SESSION_TOKEN"

__version__ = "0.1.0"

__all__ = [
    "Client",
    "Endpoints",
    "RetryPolicy",
    "AgentrouterError",
    "FailedPreconditionError",
    "STANDARD_API_KEY_ENV",
    "STANDARD_BASE_URL_ENV",
    "STANDARD_SESSION_TOKEN_ENV",
    "ABORTED",
    "ALREADY_EXISTS",
    "DEADLINE_EXCEEDED",
    "INVALID_ARGUMENT",
    "NOT_FOUND",
    "PERMISSION_DENIED",
    "RETRYABLE",
    "UNAUTHENTICATED",
    "UNAVAILABLE",
    "UNKNOWN",
    "__version__",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/auth/v1/auth_options.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/auth/v1/auth_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftars/auth/v1/auth_options.proto\x12\x0ctars.auth.v1\x1a google/protobuf/descriptor.proto\"\\\n\x0b\x41uthOptions\x12\x35\n\nauth_types\x18\x01 \x03(\x0e\x32\x16.tars.auth.v1.AuthTypeR\tauthTypes\x12\x16\n\x06scopes\x18\x02 \x03(\tR\x06scopes*u\n\x08\x41uthType\x12\x19\n\x15\x41UTH_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x41UTH_TYPE_API_KEY\x10\x01\x12\x1d\n\x19\x41UTH_TYPE_SERVICE_ACCOUNT\x10\x02\x12\x18\n\x14\x41UTH_TYPE_USER_TOKEN\x10\x03:O\n\x04\x61uth\x12\x1e.google.protobuf.MethodOptions\x18\xd1\x86\x03 \x01(\x0b\x32\x19.tars.auth.v1.AuthOptionsR\x04\x61uth:I\n\x10project_id_field\x12\x1d.google.protobuf.FieldOptions\x18\xd7\x86\x03 \x01(\x08R\x0eprojectIdField:K\n\x11\x63ustomer_id_field\x12\x1d.google.protobuf.FieldOptions\x18\xd8\x86\x03 \x01(\x08R\x0f\x63ustomerIdFieldBv\n\x10\x63om.tars.auth.v1B\x10\x41uthOptionsProtoP\x01\xa2\x02\x03TAX\xaa\x02\x0cTars.Auth.V1\xca\x02\x0cTars\\Auth\\V1\xe2\x02\x18Tars\\Auth\\V1\\GPBMetadata\xea\x02\x0eTars::Auth::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.auth.v1.auth_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.tars.auth.v1B\020AuthOptionsProtoP\001\242\002\003TAX\252\002\014Tars.Auth.V1\312\002\014Tars\\Auth\\V1\342\002\030Tars\\Auth\\V1\\GPBMetadata\352\002\016Tars::Auth::V1'
  _globals['_AUTHTYPE']._serialized_start=177
  _globals['_AUTHTYPE']._serialized_end=294
  _globals['_AUTHOPTIONS']._serialized_start=83
  _globals['_AUTHOPTIONS']._serialized_end=175
# @@protoc_insertion_point(module_scope)



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Provider(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROVIDER_UNSPECIFIED: _ClassVar[Provider]
    PROVIDER_OPENAI: _ClassVar[Provider]
    PROVIDER_ANTHROPIC: _ClassVar[Provider]
    PROVIDER_AZURE_OPENAI: _ClassVar[Provider]
    PROVIDER_GOOGLE_VERTEX: _ClassVar[Provider]
    PROVIDER_AWS_BEDROCK: _ClassVar[Provider]
PROVIDER_UNSPECIFIED: Provider
PROVIDER_OPENAI: Provider
PROVIDER_ANTHROPIC: Provider
PROVIDER_AZURE_OPENAI: Provider
PROVIDER_GOOGLE_VERTEX: Provider
PROVIDER_AWS_BEDROCK: Provider

class AiKey(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "provider", "name", "display_suffix", "user_scope", "scope_user_id", "created_at", "updated_at", "revoked_at", "secret_ref")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_SUFFIX_FIELD_NUMBER: _ClassVar[int]
    USER_SCOPE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    SECRET_REF_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    provider: Provider
    name: str
    display_suffix: str
    user_scope: bool
    scope_user_id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    revoked_at: _timestamp_pb2.Timestamp
    secret_ref: str
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., provider: _Optional[_Union[Provider, str]] = ..., name: _Optional[str] = ..., display_suffix: _Optional[str] = ..., user_scope: _Optional[bool] = ..., scope_user_id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., secret_ref: _Optional[str] = ...) -> None: ...

class RegisterRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "provider", "name", "secret", "user_scope")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    USER_SCOPE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    provider: Provider
    name: str
    secret: str
    user_scope: bool
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., provider: _Optional[_Union[Provider, str]] = ..., name: _Optional[str] = ..., secret: _Optional[str] = ..., user_scope: _Optional[bool] = ...) -> None: ...

class RegisterResponse(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: AiKey
    def __init__(self, key: _Optional[_Union[AiKey, _Mapping]] = ...) -> None: ...

class GetRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GetResponse(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: AiKey
    def __init__(self, key: _Optional[_Union[AiKey, _Mapping]] = ...) -> None: ...

class ListRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListResponse(_message.Message):
    __slots__ = ("keys",)
    KEYS_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedCompositeFieldContainer[AiKey]
    def __init__(self, keys: _Optional[_Iterable[_Union[AiKey, _Mapping]]] = ...) -> None: ...

class RevokeRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class RevokeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FetchRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class FetchResponse(_message.Message):
    __slots__ = ("provider", "secret", "display_suffix")
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_SUFFIX_FIELD_NUMBER: _ClassVar[int]
    provider: Provider
    secret: str
    display_suffix: str
    def __init__(self, provider: _Optional[_Union[Provider, str]] = ..., secret: _Optional[str] = ..., display_suffix: _Optional[str] = ...) -> None: ...



from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetJWKSRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetJWKSResponse(_message.Message):
    __slots__ = ("keys",)
    KEYS_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedCompositeFieldContainer[JWK]
    def __init__(self, keys: _Optional[_Iterable[_Union[JWK, _Mapping]]] = ...) -> None: ...

class JWK(_message.Message):
    __slots__ = ("kid", "kty", "alg", "use", "crv", "x", "y")
    KID_FIELD_NUMBER: _ClassVar[int]
    KTY_FIELD_NUMBER: _ClassVar[int]
    ALG_FIELD_NUMBER: _ClassVar[int]
    USE_FIELD_NUMBER: _ClassVar[int]
    CRV_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    kid: str
    kty: str
    alg: str
    use: str
    crv: str
    x: str
    y: str
    def __init__(self, kid: _Optional[str] = ..., kty: _Optional[str] = ..., alg: _Optional[str] = ..., use: _Optional[str] = ..., crv: _Optional[str] = ..., x: _Optional[str] = ..., y: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/registry/v1/registry.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/registry/v1/registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftars/registry/v1/registry.proto\x12\x10tars.registry.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"\xc6\x05\n\x1dRegisterServiceAccountRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12*\n\x0c\x63lient_email\x18\x03 \x01(\tB\x07\xbaH\x04r\x02`\x01R\x0b\x63lientEmail\x12\x30\n\x0eprivate_key_id\x18\x04 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x0cprivateKeyId\x12\"\n\x06issuer\x18\x05 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\x06issuer\x12&\n\x08\x61udience\x18\x06 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xfd\x01R\x08\x61udience\x12(\n\x08jwks_uri\x18\x07 \x01(\tB\x08\xbaH\x05r\x03\x88\x01\x01H\x00R\x07jwksUri\x88\x01\x01\x12\x31\n\x06scopes\x18\x08 \x03(\tB\x19\xbaH\x16\x92\x01\x13\x10\n\"\x0fr\r\x18\x32\x32\t^[a-z_]+$R\x06scopes\x12\x41\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\texpiresAt\x12\x46\n\x0bpublic_keys\x18\n \x03(\x0b\x32\x1b.tars.registry.v1.PublicKeyB\x08\xbaH\x05\x92\x01\x02\x08\x01R\npublicKeys\x12\x1f\n\x08\x63hecksum\x18\x0b \x01(\tH\x01R\x08\x63hecksum\x88\x01\x01\x12\x32\n\x12\x63hecksum_algorithm\x18\x0c \x01(\tH\x02R\x11\x63hecksumAlgorithm\x88\x01\x01\x42\x0b\n\t_jwks_uriB\x0b\n\t_checksumB\x15\n\x13_checksum_algorithm\"\x85\x01\n\x1eRegisterServiceAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"i\n\x1bRevokeServiceAccountRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x02id\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"\x83\x01\n\x1cRevokeServiceAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"4\n\x18GetServiceAccountRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x02id\"j\n\x19GetServiceAccountResponse\x12M\n\x0fservice_account\x18\x01 \x01(\x0b\x32$.tars.registry.v1.ServiceAccountInfoR\x0eserviceAccount\"\xde\x01\n\x1bLookupServiceAccountRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12\x30\n\x0eprivate_key_id\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x0cprivateKeyId\"m\n\x1cLookupServiceAccountResponse\x12M\n\x0fservice_account\x18\x01 \x01(\x0b\x32$.tars.registry.v1.ServiceAccountInfoR\x0eserviceAccount\"\xef\x02\n\x1aListServiceAccountsRequest\x12N\n\x0b\x63ustomer_id\x18\x01 \x01(\tB(\xbaH%r#\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$H\x00R\ncustomerId\x88\x01\x01\x12\x43\n\x0cworkspace_id\x18\x02 \x01(\tB\x1b\xbaH\x18r\x16\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$H\x01R\x0bworkspaceId\x88\x01\x01\x12,\n\x0finclude_revoked\x18\x03 \x01(\x08H\x02R\x0eincludeRevoked\x88\x01\x01\x12&\n\tpage_size\x18\x04 \x01(\x05\x42\t\xbaH\x06\x1a\x04\x18\x64(\x01R\x08pageSize\x12\"\n\npage_token\x18\x05 \x01(\tH\x03R\tpageToken\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x0f\n\r_workspace_idB\x12\n\x10_include_revokedB\r\n\x0b_page_token\"\xd0\x01\n\x1bListServiceAccountsResponse\x12O\n\x10service_accounts\x18\x01 \x03(\x0b\x32$.tars.registry.v1.ServiceAccountInfoR\x0fserviceAccounts\x12+\n\x0fnext_page_token\x18\x02 \x01(\tH\x00R\rnextPageToken\x88\x01\x01\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCountB\x12\n\x10_next_page_token\"\\\n\"GetServiceAccountPublicKeysRequest\x12\x36\n\x12service_account_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x10serviceAccountId\"c\n#GetServiceAccountPublicKeysResponse\x12<\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32\x1b.tars.registry.v1.PublicKeyR\npublicKeys\"\xa7\x05\n\x12ServiceAccountInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x03 \x01(\tR\x0bworkspaceId\x12!\n\x0c\x63lient_email\x18\x04 \x01(\tR\x0b\x63lientEmail\x12$\n\x0eprivate_key_id\x18\x05 \x01(\tR\x0cprivateKeyId\x12\x16\n\x06issuer\x18\x06 \x01(\tR\x06issuer\x12\x1a\n\x08\x61udience\x18\x07 \x01(\tR\x08\x61udience\x12\x1e\n\x08jwks_uri\x18\x08 \x01(\tH\x00R\x07jwksUri\x88\x01\x01\x12\x16\n\x06scopes\x18\t \x03(\tR\x06scopes\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nexpires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12>\n\nrevoked_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\trevokedAt\x88\x01\x01\x12*\n\x0erevoked_reason\x18\r \x01(\tH\x02R\rrevokedReason\x88\x01\x01\x12\x1f\n\x08\x63hecksum\x18\x0e \x01(\tH\x03R\x08\x63hecksum\x88\x01\x01\x12\x32\n\x12\x63hecksum_algorithm\x18\x0f \x01(\tH\x04R\x11\x63hecksumAlgorithm\x88\x01\x01\x42\x0b\n\t_jwks_uriB\r\n\x0b_revoked_atB\x11\n\x0f_revoked_reasonB\x0b\n\t_checksumB\x15\n\x13_checksum_algorithm\"\xd7\x01\n\tPublicKey\x12\x1c\n\x03kid\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\x80\x02R\x03kid\x12,\n\x03\x61lg\x18\x02 \x01(\tB\x1a\xbaH\x17r\x15R\x05\x45S256R\x05\x45S384R\x05\x45S512R\x03\x61lg\x12!\n\x03use\x18\x03 \x01(\tB\x0f\xbaH\x0cr\nR\x03sigR\x03\x65ncR\x03use\x12 \n\x07key_pem\x18\x04 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06keyPem\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xc5\x02\n\x1f\x43reateRegistryCredentialRequest\x12K\n\x0b\x63ustomer_id\x18\x01 \x01(\tB*\xbaH\'r%\x10\x01\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$R\ncustomerId\x12@\n\x0cworkspace_id\x18\x02 \x01(\tB\x1d\xbaH\x1ar\x18\x10\x01\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$R\x0bworkspaceId\x12,\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0b\x64\x65scription\x12>\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\texpiresAt\x88\x01\x01\x12\x16\n\x06scopes\x18\x05 \x03(\tR\x06scopesB\r\n\x0b_expires_at\"\xbf\x01\n CreateRegistryCredentialResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x18\n\x07message\x18\x05 \x01(\tR\x07message\"\xf3\x02\n\x1eListRegistryCredentialsRequest\x12N\n\x0b\x63ustomer_id\x18\x01 \x01(\tB(\xbaH%r#\x18?2\x1f^[a-z0-9]([a-z0-9-]*[a-z0-9])?$H\x00R\ncustomerId\x88\x01\x01\x12\x43\n\x0cworkspace_id\x18\x02 \x01(\tB\x1b\xbaH\x18r\x16\x18\xfd\x01\x32\x11^[a-zA-Z0-9-_.]+$H\x01R\x0bworkspaceId\x88\x01\x01\x12,\n\x0finclude_revoked\x18\x03 \x01(\x08H\x02R\x0eincludeRevoked\x88\x01\x01\x12&\n\tpage_size\x18\x04 \x01(\x05\x42\t\xbaH\x06\x1a\x04\x18\x64(\x01R\x08pageSize\x12\"\n\npage_token\x18\x05 \x01(\tH\x03R\tpageToken\x88\x01\x01\x42\x0e\n\x0c_customer_idB\x0f\n\r_workspace_idB\x12\n\x10_include_revokedB\r\n\x0b_page_token\"\xcf\x01\n\x1fListRegistryCredentialsResponse\x12J\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32(.tars.registry.v1.RegistryCredentialInfoR\x0b\x63redentials\x12+\n\x0fnext_page_token\x18\x02 \x01(\tH\x00R\rnextPageToken\x88\x01\x01\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCountB\x12\n\x10_next_page_token\"m\n\x1fRevokeRegistryCredentialRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\xb0\x01\x01R\x02id\x12%\n\x06reason\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03H\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"\x87\x01\n RevokeRegistryCredentialResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"\x80\x05\n\x16RegistryCredentialInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63ustomer_id\x18\x02 \x01(\tR\ncustomerId\x12!\n\x0cworkspace_id\x18\x03 \x01(\tR\x0bworkspaceId\x12\x1a\n\x08username\x18\x04 \x01(\tR\x08username\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06scopes\x18\x06 \x03(\tR\x06scopes\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x1d\n\ncreated_by\x18\x08 \x01(\tR\tcreatedBy\x12>\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\texpiresAt\x88\x01\x01\x12\x41\n\x0clast_used_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\nlastUsedAt\x88\x01\x01\x12>\n\nrevoked_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\trevokedAt\x88\x01\x01\x12*\n\x0erevoked_reason\x18\x0c \x01(\tH\x03R\rrevokedReason\x88\x01\x01\x12\"\n\nrevoked_by\x18\r \x01(\tH\x04R\trevokedBy\x88\x01\x01\x42\r\n\x0b_expires_atB\x0f\n\r_last_used_atB\r\n\x0b_revoked_atB\x11\n\x0f_revoked_reasonB\r\n\x0b_revoked_by\"\r\n\x0bPingRequest\"b\n\x0cPingResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp2\xc7\x0e\n\x0fRegistryService\x12\xb3\x01\n\x16RegisterServiceAccount\x12/.tars.registry.v1.RegisterServiceAccountRequest\x1a\x30.tars.registry.v1.RegisterServiceAccountResponse\"6\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\"\"\x1d/registry/v1/service-accounts:\x01*\x12\xb9\x01\n\x14RevokeServiceAccount\x12-.tars.registry.v1.RevokeServiceAccountRequest\x1a..tars.registry.v1.RevokeServiceAccountResponse\"B\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02.\")/registry/v1/service-accounts/{id}:revoke:\x01*\x12\xa9\x01\n\x11GetServiceAccount\x12*.tars.registry.v1.GetServiceAccountRequest\x1a+.tars.registry.v1.GetServiceAccountResponse\";\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02$\x12\"/registry/v1/service-accounts/{id}\x12\xdb\x01\n\x14LookupServiceAccount\x12-.tars.registry.v1.LookupServiceAccountRequest\x1a..tars.registry.v1.LookupServiceAccountResponse\"d\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02M\x12K/registry/v1/service-accounts/{customer_id}/{workspace_id}/{private_key_id}\x12\xaa\x01\n\x13ListServiceAccounts\x12,.tars.registry.v1.ListServiceAccountsRequest\x1a-.tars.registry.v1.ListServiceAccountsResponse\"6\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x1f\x12\x1d/registry/v1/service-accounts\x12\xe3\x01\n\x1bGetServiceAccountPublicKeys\x12\x34.tars.registry.v1.GetServiceAccountPublicKeysRequest\x1a\x35.tars.registry.v1.GetServiceAccountPublicKeysResponse\"W\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02@\x12>/registry/v1/service-accounts/{service_account_id}/public-keys\x12\xb4\x01\n\x18\x43reateRegistryCredential\x12\x31.tars.registry.v1.CreateRegistryCredentialRequest\x1a\x32.tars.registry.v1.CreateRegistryCredentialResponse\"1\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x1d\"\x18/registry/v1/credentials:\x01*\x12\xb1\x01\n\x17ListRegistryCredentials\x12\x30.tars.registry.v1.ListRegistryCredentialsRequest\x1a\x31.tars.registry.v1.ListRegistryCredentialsResponse\"1\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x1a\x12\x18/registry/v1/credentials\x12\xc0\x01\n\x18RevokeRegistryCredential\x12\x31.tars.registry.v1.RevokeRegistryCredentialRequest\x1a\x32.tars.registry.v1.RevokeRegistryCredentialResponse\"=\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02)\"$/registry/v1/credentials/{id}:revoke:\x01*\x12q\n\x04Ping\x12\x1d.tars.registry.v1.PingRequest\x1a\x1e.tars.registry.v1.PingResponse\"*\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\x82\xd3\xe4\x93\x02\x13\x12\x11/registry/v1/ping\x1a\x04\xa0\xb5\x18\x01\x42\x87\x01\n\x14\x63om.tars.registry.v1B\rRegistryProtoP\x01\xa2\x02\x03TRX\xaa\x02\x10Tars.Registry.V1\xca\x02\x10Tars\\Registry\\V1\xe2\x02\x1cTars\\Registry\\V1\\GPBMetadata\xea\x02\x12Tars::Registry::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.registry.v1.registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.registry.v1B\rRegistryProtoP\001\242\002\003TRX\252\002\020Tars.Registry.V1\312\002\020Tars\\Registry\\V1\342\002\034Tars\\Registry\\V1\\GPBMetadata\352\002\022Tars::Registry::V1'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['client_email']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['client_email']._serialized_options = b'\272H\004r\002`\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['issuer']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['issuer']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['audience']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['audience']._serialized_options = b'\272H\007r\005\020\001\030\375\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['jwks_uri']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['jwks_uri']._serialized_options = b'\272H\005r\003\210\001\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['scopes']._serialized_options = b'\272H\026\222\001\023\020\n\"\017r\r\03022\t^[a-z_]+$'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['expires_at']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['expires_at']._serialized_options = b'\272H\003\310\001\001'
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['public_keys']._loaded_options = None
  _globals['_REGISTERSERVICEACCOUNTREQUEST'].fields_by_name['public_keys']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_REVOKESERVICEACCOUNTREQUEST'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_GETSERVICEACCOUNTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSERVICEACCOUNTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._loaded_options = None
  _globals['_LOOKUPSERVICEACCOUNTREQUEST'].fields_by_name['private_key_id']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H%r#\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\030r\026\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSERVICEACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\006\032\004\030d(\001'
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_PUBLICKEY'].fields_by_name['kid']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['kid']._serialized_options = b'\272H\007r\005\020\001\030\200\002'
  _globals['_PUBLICKEY'].fields_by_name['alg']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['alg']._serialized_options = b'\272H\027r\025R\005ES256R\005ES384R\005ES512'
  _globals['_PUBLICKEY'].fields_by_name['use']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['use']._serialized_options = b'\272H\014r\nR\003sigR\003enc'
  _globals['_PUBLICKEY'].fields_by_name['key_pem']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['key_pem']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H\'r%\020\001\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\032r\030\020\001\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEREGISTRYCREDENTIALREQUEST'].fields_by_name['description']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\272H%r#\030?2\037^[a-z0-9]([a-z0-9-]*[a-z0-9])?$'
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\272H\030r\026\030\375\0012\021^[a-zA-Z0-9-_.]+$'
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTREGISTRYCREDENTIALSREQUEST'].fields_by_name['page_size']._serialized_options = b'\272H\006\032\004\030d(\001'
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['id']._serialized_options = b'\272H\005r\003\260\001\001'
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['reason']._loaded_options = None
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST'].fields_by_name['reason']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_REGISTRYSERVICE']._loaded_options = None
  _globals['_REGISTRYSERVICE']._serialized_options = b'\240\265\030\001'
  _globals['_REGISTRYSERVICE'].methods_by_name['RegisterServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['RegisterServiceAccount']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\"\"\035/registry/v1/service-accounts:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeServiceAccount']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002.\")/registry/v1/service-accounts/{id}:revoke:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccount']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002$\022\"/registry/v1/service-accounts/{id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['LookupServiceAccount']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['LookupServiceAccount']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002M\022K/registry/v1/service-accounts/{customer_id}/{workspace_id}/{private_key_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListServiceAccounts']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListServiceAccounts']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\037\022\035/registry/v1/service-accounts'
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccountPublicKeys']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['GetServiceAccountPublicKeys']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002@\022>/registry/v1/service-accounts/{service_account_id}/public-keys'
  _globals['_REGISTRYSERVICE'].methods_by_name['CreateRegistryCredential']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['CreateRegistryCredential']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\035\"\030/registry/v1/credentials:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListRegistryCredentials']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListRegistryCredentials']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\032\022\030/registry/v1/credentials'
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeRegistryCredential']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['RevokeRegistryCredential']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002)\"$/registry/v1/credentials/{id}:revoke:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Ping']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Ping']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\202\323\344\223\002\023\022\021/registry/v1/ping'
  _globals['_REGISTERSERVICEACCOUNTREQUEST']._serialized_start=204
  _globals['_REGISTERSERVICEACCOUNTREQUEST']._serialized_end=914
  _globals['_REGISTERSERVICEACCOUNTRESPONSE']._serialized_start=917
  _globals['_REGISTERSERVICEACCOUNTRESPONSE']._serialized_end=1050
  _globals['_REVOKESERVICEACCOUNTREQUEST']._serialized_start=1052
  _globals['_REVOKESERVICEACCOUNTREQUEST']._serialized_end=1157
  _globals['_REVOKESERVICEACCOUNTRESPONSE']._serialized_start=1160
  _globals['_REVOKESERVICEACCOUNTRESPONSE']._serialized_end=1291
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_start=1293
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_end=1345
  _globals['_GETSERVICEACCOUNTRESPONSE']._serialized_start=1347
  _globals['_GETSERVICEACCOUNTRESPONSE']._serialized_end=1453
  _globals['_LOOKUPSERVICEACCOUNTREQUEST']._serialized_start=1456
  _globals['_LOOKUPSERVICEACCOUNTREQUEST']._serialized_end=1678
  _globals['_LOOKUPSERVICEACCOUNTRESPONSE']._serialized_start=1680
  _globals['_LOOKUPSERVICEACCOUNTRESPONSE']._serialized_end=1789
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_start=1792
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_end=2159
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_start=2162
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_end=2370
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST']._serialized_start=2372
  _globals['_GETSERVICEACCOUNTPUBLICKEYSREQUEST']._serialized_end=2464
  _globals['_GETSERVICEACCOUNTPUBLICKEYSRESPONSE']._serialized_start=2466
  _globals['_GETSERVICEACCOUNTPUBLICKEYSRESPONSE']._serialized_end=2565
  _globals['_SERVICEACCOUNTINFO']._serialized_start=2568
  _globals['_SERVICEACCOUNTINFO']._serialized_end=3247
  _globals['_PUBLICKEY']._serialized_start=3250
  _globals['_PUBLICKEY']._serialized_end=3465
  _globals['_CREATEREGISTRYCREDENTIALREQUEST']._serialized_start=3468
  _globals['_CREATEREGISTRYCREDENTIALREQUEST']._serialized_end=3793
  _globals['_CREATEREGISTRYCREDENTIALRESPONSE']._serialized_start=3796
  _globals['_CREATEREGISTRYCREDENTIALRESPONSE']._serialized_end=3987
  _globals['_LISTREGISTRYCREDENTIALSREQUEST']._serialized_start=3990
  _globals['_LISTREGISTRYCREDENTIALSREQUEST']._serialized_end=4361
  _globals['_LISTREGISTRYCREDENTIALSRESPONSE']._serialized_start=4364
  _globals['_LISTREGISTRYCREDENTIALSRESPONSE']._serialized_end=4571
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST']._serialized_start=4573
  _globals['_REVOKEREGISTRYCREDENTIALREQUEST']._serialized_end=4682
  _globals['_REVOKEREGISTRYCREDENTIALRESPONSE']._serialized_start=4685
  _globals['_REVOKEREGISTRYCREDENTIALRESPONSE']._serialized_end=4820
  _globals['_REGISTRYCREDENTIALINFO']._serialized_start=4823
  _globals['_REGISTRYCREDENTIALINFO']._serialized_end=5463
  _globals['_PINGREQUEST']._serialized_start=5465
  _globals['_PINGREQUEST']._serialized_end=5478
  _globals['_PINGRESPONSE']._serialized_start=5480
  _globals['_PINGRESPONSE']._serialized_end=5578
  _globals['_REGISTRYSERVICE']._serialized_start=5581
  _globals['_REGISTRYSERVICE']._serialized_end=7444
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/errors/v1/reasons.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/errors/v1/reasons.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctars/errors/v1/reasons.proto\x12\x0etars.errors.v1*\xec\x03\n\x0b\x45rrorReason\x12\x1c\n\x18\x45RROR_REASON_UNSPECIFIED\x10\x00\x12!\n\x1d\x45RROR_REASON_INVALID_ARGUMENT\x10\x01\x12 \n\x1c\x45RROR_REASON_UNAUTHENTICATED\x10\x02\x12\"\n\x1e\x45RROR_REASON_PERMISSION_DENIED\x10\x03\x12\x1a\n\x16\x45RROR_REASON_NOT_FOUND\x10\x04\x12\x1f\n\x1b\x45RROR_REASON_ALREADY_EXISTS\x10\x05\x12$\n ERROR_REASON_FAILED_PRECONDITION\x10\x06\x12\x19\n\x15\x45RROR_REASON_INTERNAL\x10\x07\x12\x1c\n\x18\x45RROR_REASON_UNAVAILABLE\x10\x08\x12 \n\x1c\x45RROR_REASON_MODEL_NOT_FOUND\x10\x64\x12 \n\x1c\x45RROR_REASON_MODEL_AMBIGUOUS\x10\x65\x12#\n\x1f\x45RROR_REASON_PROVIDER_NOT_FOUND\x10\x66\x12$\n ERROR_REASON_CROSS_TENANT_DENIED\x10g\x12+\n\'ERROR_REASON_SESSION_DEFAULT_UNRESOLVED\x10hB\xb5\x01\n\x12\x63om.tars.errors.v1B\x0cReasonsProtoP\x01Z7github.com/tetrateio/fraser/api/tars/errors/v1;errorsv1\xa2\x02\x03TEX\xaa\x02\x0eTars.Errors.V1\xca\x02\x0eTars\\Errors\\V1\xe2\x02\x1aTars\\Errors\\V1\\GPBMetadata\xea\x02\x10Tars::Errors::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.errors.v1.reasons_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.tars.errors.v1B\014ReasonsProtoP\001Z7github.com/tetrateio/fraser/api/tars/errors/v1;errorsv1\242\002\003TEX\252\002\016Tars.Errors.V1\312\002\016Tars\\Errors\\V1\342\002\032Tars\\Errors\\V1\\GPBMetadata\352\002\020Tars::Errors::V1'
  _globals['_ERRORREASON']._serialized_start=49
  _globals['_ERRORREASON']._serialized_end=541
# @@protoc_insertion_point(module_scope)
